@@ -16,9 +16,9 @@
 #include <KLocalizedString>
 
 LocalCalendar::LocalCalendar(QObject *parent)
-    : QObject(parent), m_config {new CalindoriConfig(this)}, m_alarm_checker {new AlarmChecker(this)}
+    : QObject(parent), m_alarm_checker {new AlarmChecker(this)}
 {
-    loadCalendar(m_config->activeCalendar());
+    loadCalendar(CalindoriConfig::instance().activeCalendar());
 }
 
 LocalCalendar::~LocalCalendar() = default;
@@ -41,15 +41,6 @@ void LocalCalendar::setName(const QString &calendarName)
     }
 }
 
-void LocalCalendar::setCalendar(KCalendarCore::Calendar::Ptr calendar)
-{
-    if (m_calendar != calendar) {
-        m_calendar = calendar;
-    }
-
-    Q_EMIT calendarChanged();
-}
-
 int LocalCalendar::todosCount(const QDate &date) const
 {
     if (m_calendar == nullptr) {
@@ -95,27 +86,27 @@ bool LocalCalendar::save()
 QVariantMap LocalCalendar::canCreateFile(const QString &calendarName)
 {
     QVariantMap result;
-    result["success"] = QVariant(true);
-    result["reason"] = QVariant(QString());
+    result[QStringLiteral("success")] = QVariant(true);
+    result[QStringLiteral("reason")] = QVariant(QString());
 
-    QString targetPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/calindori_" + calendarName + ".ics" ;
+    QString targetPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/calindori_") + calendarName + QStringLiteral(".ics");
     QFile calendarFile(targetPath);
 
     if (calendarFile.exists()) {
-        result["success"] = QVariant(false);
-        result["reason"] = QVariant(QString(i18n("A calendar with the same name already exists")));
+        result[QStringLiteral("success")] = QVariant(false);
+        result[QStringLiteral("reason")] = QVariant(QString(i18n("A calendar with the same name already exists")));
 
         return result;
     }
 
-    result["targetPath"] = QVariant(QString(targetPath));
+    result[QStringLiteral("targetPath")] = QVariant(QString(targetPath));
 
     return result;
 }
 
 void LocalCalendar::loadCalendar(const QString &calendarName)
 {
-    m_fullpath = m_config->calendarFile(calendarName);
+    m_fullpath = CalindoriConfig::instance().calendarFile(calendarName);
 
     if (loadStorage()) {
         m_name = calendarName;
@@ -175,29 +166,34 @@ bool LocalCalendar::loadStorage()
 
 QString LocalCalendar::ownerName() const
 {
-    return m_config->ownerName(m_name);
+    return CalindoriConfig::instance().ownerName(m_name);
 }
 
 QString LocalCalendar::ownerEmail() const
 {
-    return m_config->ownerEmail(m_name);
+    return CalindoriConfig::instance().ownerEmail(m_name);
 }
 
 bool LocalCalendar::isExternal() const
 {
-    return m_config->isExternal(m_name);
+    return CalindoriConfig::instance().isExternal(m_name);
 }
 
 void LocalCalendar::setOwnerName(const QString &ownerName)
 {
-    m_config->setOwnerName(m_name, ownerName);
+    CalindoriConfig::instance().setOwnerName(m_name, ownerName);
 
     Q_EMIT ownerNameChanged();
 }
 
 void LocalCalendar::setOwnerEmail(const QString &ownerEmail)
 {
-    m_config->setOwnerEmail(m_name, ownerEmail);
+    CalindoriConfig::instance().setOwnerEmail(m_name, ownerEmail);
 
     Q_EMIT ownerEmailChanged();
 }
+
+KCalendarCore::Calendar *LocalCalendar::calendarRaw() const
+{
+    return m_calendar.data();
+}
